[PATCH 2 of 2 STABLE] mq: rename the --mq option to --queue

Dan Villiom Podlaski Christiansen danchr at gmail.com
Thu Mar 4 06:05:13 CST 2010


# HG changeset patch
# User Dan Villiom Podlaski Christiansen <danchr at gmail.com>
# Date 1267704180 -3600
# Node ID 1694d2b0e58b0e25d53bad25cd0ff817d6841e2b
# Parent  a65fff12883a4872ff0312ac29dc392164fc3468
mq: rename the --mq option to --queue.

Long options should consist of proper words rather than
abbreviations. The translations have been updated to reflect this, as
doing so is trivial.

diff --git a/i18n/da.po b/i18n/da.po
--- a/i18n/da.po
+++ b/i18n/da.po
@@ -3059,13 +3059,13 @@ msgstr "omdøber %s til %s\n"
 msgid ""
 "restore the queue state saved by a revision (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 
 msgid ""
 "save current queue state (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 
 #, python-format
diff --git a/i18n/ja.po b/i18n/ja.po
--- a/i18n/ja.po
+++ b/i18n/ja.po
@@ -3205,20 +3205,20 @@ msgstr "%s から %s に改名中\n"
 msgid ""
 "restore the queue state saved by a revision (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 "指定リビジョンによって保存されたパッチ管理状態の復旧(非推奨)\n"
 "\n"
-"    本コマンドは非推奨です。--mq 指定によるリベースをしてください。"
+"    本コマンドは非推奨です。--queue 指定によるリベースをしてください。"
 
 msgid ""
 "save current queue state (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 "パッチ管理状態の保存(非推奨)\n"
 "\n"
-"    本コマンドは非推奨です。--mq 指定によるリベースをしてください。"
+"    本コマンドは非推奨です。--queue 指定によるリベースをしてください。"
 
 #, python-format
 msgid "destination %s exists and is not a directory"
diff --git a/i18n/pt_BR.po b/i18n/pt_BR.po
--- a/i18n/pt_BR.po
+++ b/i18n/pt_BR.po
@@ -3856,19 +3856,19 @@ msgstr "renomeando %s para %s\n"
 msgid ""
 "restore the queue state saved by a revision (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 "restaura o estado da fila salvo por uma revisão (OBSOLETO)\n"
 "\n"
-"    Este comando é obsoleto, use rebase --mq em seu lugar."
+"    Este comando é obsoleto, use rebase --queue em seu lugar."
 
 msgid ""
 "save current queue state (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 "salva o estado atual da fila (OBSOLETO)\n"
-"    Este comando é obsoleto, use rebase --mq em seu lugar."
+"    Este comando é obsoleto, use rebase --queue em seu lugar."
 
 #, python-format
 msgid "destination %s exists and is not a directory"
diff --git a/i18n/sv.po b/i18n/sv.po
--- a/i18n/sv.po
+++ b/i18n/sv.po
@@ -2739,13 +2739,13 @@ msgstr "döper om %s till %s\n"
 msgid ""
 "restore the queue state saved by a revision (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 
 msgid ""
 "save current queue state (DEPRECATED)\n"
 "\n"
-"    This command is deprecated, use rebase --mq instead."
+"    This command is deprecated, use rebase --queue instead."
 msgstr ""
 
 #, python-format
diff --git a/tests/test-mq-qclone-http b/tests/test-mq-qclone-http
--- a/tests/test-mq-qclone-http
+++ b/tests/test-mq-qclone-http
@@ -76,6 +76,6 @@ hg --cwd d log --template "{desc}\n"
 hg --cwd d qpush -a
 hg --cwd d log --template "{desc}\n"
 
-echo '% test --mq works and uses correct repository config'
-hg --cwd d outgoing --mq | sed "s|$HGPORT2|\$HGPORT2|"
-hg --cwd d log --mq --template '{rev} {desc|firstline}\n'
+echo '% test --queue works and uses correct repository config'
+hg --cwd d outgoing --queue | sed "s|$HGPORT2|\$HGPORT2|"
+hg --cwd d log --queue --template '{rev} {desc|firstline}\n'
diff --git a/tests/test-mq-qclone-http.out b/tests/test-mq-qclone-http.out
--- a/tests/test-mq-qclone-http.out
+++ b/tests/test-mq-qclone-http.out
@@ -78,7 +78,7 @@ applying b.patch
 now at: b.patch
 imported patch b.patch
 a
-% test --mq works and uses correct repository config
+% test --queue works and uses correct repository config
 comparing with http://localhost:$HGPORT2/a/.hg/patches
 searching for changes
 no changes found


More information about the Mercurial-devel mailing list
diff --git a/hgext/mq.py b/hgext/mq.py
--- a/hgext/mq.py
+++ b/hgext/mq.py
@@ -2335,7 +2335,7 @@ def rename(ui, repo, patch, name=None, *
 def restore(ui, repo, rev, **opts):
     """restore the queue state saved by a revision (DEPRECATED)
 
-    This command is deprecated, use rebase --mq instead."""
+    This command is deprecated, use rebase --queue instead."""
     rev = repo.lookup(rev)
     q = repo.mq
     q.restore(repo, rev, delete=opts['delete'],
@@ -2346,7 +2346,7 @@ def restore(ui, repo, rev, **opts):
 def save(ui, repo, **opts):
     """save current queue state (DEPRECATED)
 
-    This command is deprecated, use rebase --mq instead."""
+    This command is deprecated, use rebase --queue instead."""
     q = repo.mq
     message = cmdutil.logmessage(opts)
     ret = q.save(repo, msg=message)
@@ -2629,7 +2629,7 @@ def mqimport(orig, ui, repo, *args, **kw
     return orig(ui, repo, *args, **kwargs)
 
 def mqinit(orig, ui, *args, **kwargs):
-    mq = kwargs.pop('mq', None)
+    mq = kwargs.pop('queue', None)
 
     if not mq:
         return orig(ui, *args, **kwargs)
@@ -2639,10 +2639,10 @@ def mqinit(orig, ui, *args, **kwargs):
     return qinit(ui, repo, True)
 
 def mqcommand(orig, ui, repo, *args, **kwargs):
     """Add --mq option to operate on patch repository instead of main"""
 
     # some commands do not like getting unknown options
-    mq = kwargs.pop('mq', None)
+    mq = kwargs.pop('queue', None)
 
     if not mq:
         return orig(ui, repo, *args, **kwargs)
@@ -2654,7 +2654,7 @@ def mqcommand(orig, ui, repo, *args, **k
     return orig(r.ui, r, *args, **kwargs)
 
 def uisetup(ui):
-    mqopt = [('Q', 'mq', None, _("operate on patch repository"))]
+    mqopt = [('Q', 'queue', None, _("operate on patch repository"))]
 
     extensions.wrapcommand(commands.table, 'import', mqimport)
 
@@ -2639,10 +2639,10 @@ def mqinit(orig, ui, *args, **kwargs):
 
 def mqcommand(orig, ui, repo, *args, **kwargs):
-    """Add --mq option to operate on patch repository instead of main"""
+    """Add -Q/--queue option to operate on patch repository instead of main"""
 
     # some commands do not like getting unknown options